@@ -3,12 +3,14 @@
 pub mod aa_tree;
 pub mod abstract_structs;
 pub mod argsort;
+pub mod array_compression;
 pub mod binary_search;
 pub mod bitwise;
 pub mod chinese_remainder_theorem;
 pub mod cmp;
 pub mod combinatorics;
 pub mod division;
+pub mod divisor;
 pub mod euclidean;
 pub mod fenwick_tree;
 pub mod fenwick_tree_dual;
@@ -18,14 +20,21 @@ pub mod graph_pointer_mixed;
 pub mod graph_pointer_undirected;
 pub mod graph_trait_pointer_mixed;
 pub mod group_theory;
+pub mod group_theory_preset;
 pub mod longest_common_prefix;
+pub mod longest_increasing_sequence;
 pub mod matrix;
 pub mod matrix_dynamic;
+pub mod modular;
+pub mod modular_dynamic;
 pub mod modular_static;
 pub mod power;
+pub mod primality;
+pub mod primality_test_miller_rabin;
+pub mod prime_number;
 pub mod segment_tree;
 pub mod segment_tree_dynamic;
-pub mod sequence;
+pub mod sieve_of_eratosthenes;
 pub mod sort;
 pub mod sparse_table;
 pub mod sparse_table_dynamic;
